Struct
QmiMessageWmsRawReadOutput
since: 1.0
Description [src]
struct QmiMessageWmsRawReadOutput {
/* No available fields */
}
The QmiMessageWmsRawReadOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.0
Instance methods
qmi_message_wms_raw_read_output_get_raw_message_data
Get the ‘Raw Message Data’ field from self.
since: 1.0
qmi_message_wms_raw_read_output_ref
Atomically increments the reference count of self by one.
since: 1.0
qmi_message_wms_raw_read_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.0